import {Card} from "./card";

export class CardCollection {
    cards: Array<Card> = [];
    shuffled: boolean;

    constructor(cards?: Array<Card>) {
        this.cards = cards || this.getCards();
        this.shuffle();
    }

    remaining() {
        return this.cards.length;
    }

    shuffle() {
        let currentIndex = this.cards.length, temporaryValue, randomIndex;

        while (currentIndex != 0) {
            randomIndex = Math.floor(Math.random() * currentIndex);
            currentIndex -= 1;

            temporaryValue = this.cards[currentIndex];
            this.cards[currentIndex] = this.cards[randomIndex];
            this.cards[randomIndex] = temporaryValue;
        }

        this.shuffled = true;
    }

    drawCards(count: number) {
        return this.cards.splice(0, count);
    }

    drawCardsFromBottom(count: number) {
        return this.cards.splice(-1, count);
    }

    draw(cardCode: string) {
        let cardIndex = this.cards.map((card) => {
            return card.code;
        }).indexOf(cardCode);

        if (cardIndex < 0) {
            return false
        }

        let card = this.cards[cardIndex];
        this.cards.splice(cardIndex, 1);
        return card;
    }

    add(card: Card) {
        this.cards.push(card);
    }

    private getCards() {
        let values = [
            {key: 'A', name: 'ACE'},
            {key: '2', name: '2'},
            {key: '3', name: '3'},
            {key: '4', name: '4'},
            {key: '5', name: '5'},
            {key: '6', name: '6'},
            {key: '7', name: '7'},
            {key: '8', name: '8'},
            {key: '9', name: '9'},
            {key: '10', name: '10'},
            {key: 'J', name: 'JACK'},
            {key: 'Q', name: 'QUEEN'},
            {key: 'K', name: 'KING'}
        ];
        let suits = [
            {key: 'H', name: 'HEARTS'},
            {key: 'C', name: 'CLUBS'},
            {key: 'D', name: 'DIAMONDS'},
            {key: 'S', name: 'SPADES'}
        ];

        let cards = [];
        suits.forEach((suit) => {
            values.forEach((value) => {
                cards.push(new Card(value.name, suit.name, value.key + suit.key));
            })
        });

        return cards;
    }
}