import {expect} from 'chai';
import {CardCollection} from "../src/cardcollection";
import {Deck} from "../src/deck";
import {Card} from "../src/card";
import {Pile} from "../src/pile";

describe('CardCollection', () => {
    it('can be shuffled', () => {
        let cardCollection = new CardCollection();
        let cards = cardCollection.cards.slice();
        cardCollection.shuffle();
        expect(cardCollection.cards).to.have.members(cards);
        expect(cardCollection.cards).to.not.have.ordered.members(cards);
    });

    it('can draw a card', () => {
        let cardCollection = new CardCollection();
        let card = cardCollection.cards[0];
        expect(card).to.equal(cardCollection.drawCards(1)[0]);
        expect(cardCollection.remaining()).to.equal(51);
    });

    it('can draw a card from the bottom', () => {
        let cardCollection = new CardCollection();
        let card = cardCollection.cards[51];
        expect(card).to.equal(cardCollection.drawCardsFromBottom(1)[0]);
        expect(cardCollection.remaining()).to.equal(51);
    });

    it('can add a card to the pile', () => {
        let card = new Card('2', 'HEARTS', '2H');
        let cardCollection = new CardCollection([card]);
        cardCollection.add(card);

        expect(cardCollection.remaining()).to.equal(2);
    });

    it('can draw a selected card from the pile', () => {
        let card = new Card('2', 'HEARTS', '2H');
        let cardCollection = new CardCollection([card]);

        expect(cardCollection.draw('2H')).to.equal(card);
        expect(cardCollection.remaining()).to.equal(0);
    });

    it('cannot draw a card that is not in the pile', () => {
        let card = new Card('2', 'HEARTS', '2H');
        let cardCollection = new CardCollection([card]);

        expect(cardCollection.draw('3H')).to.be.false;
        expect(cardCollection.remaining()).to.equal(1);
    });

    it('can only draw one card', () => {
        let cardA = new Card('2', 'HEARTS', '2H');
        let cardB = new Card('2', 'HEARTS', '2H');
        let cardCollection = new CardCollection([cardA, cardB]);

        expect(cardCollection.remaining()).to.equal(2);
        cardCollection.draw('2H');
        expect(cardCollection.remaining()).to.equal(1);
    });
});
